@@ -6,8 +6,9 @@
 #include <limits>
 #include <memory>
 #include <iosfwd>
-#include <cstdint>
 #include <utility>   // swap
+#include <stdint.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <iterator>
 #include <stdexcept>
@@ -175,9 +176,17 @@ public:
 
     constexpr basic_string () : _str_literal(&TERMINAL), _length(0), _state(State::LITERAL) {}
 
+  // GCC < 6 has a bug determining return value type for literals, and they can not be detected
+  #if defined(__GNUC__) && !defined(__clang__) && __GNUC__ < 6
+    basic_string (const CharT* str) : basic_string(str, traits_type::length(str)) {}
+  #else
     template <size_type SIZE> // implicit constructor for literals, literals are expected to be null-terminated
     constexpr basic_string (const CharT (&str)[SIZE]) : _str_literal(str), _length(SIZE-1), _state(State::LITERAL) {}
 
+    template<class _CharT, typename = typename std::enable_if<std::is_same<_CharT, CharT>::value>::type>
+    explicit basic_string (const _CharT* const& str) : basic_string(str, traits_type::length(str)) {}
+  #endif
+
     explicit
     basic_string (size_type capacity) : _length(0) {
         _new_auto(capacity);
@@ -188,10 +197,6 @@ public:
         traits_type::copy(_str, str, len);
     }
 
-    template<class _CharT, typename = typename std::enable_if<std::is_same<_CharT, CharT>::value>::type>
-    explicit
-    basic_string (const _CharT* const& str) : basic_string(str, traits_type::length(str)) {}
-
     basic_string (CharT* str, size_type len, size_type capacity, dtor_fn dtor) {
         _new_external(str, len, capacity, dtor, (ExternalShared*)Alloc::allocate(EBUF_CHARS), &Alloc::deallocate);
     }
